@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,19 +24,18 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <CLI.h>
 #include <Color.h>
-#include <Pig.h>
-#include <shared.h>
-#include <format.h>
-#include <utf8.h>
-#include <sstream>
-#include <algorithm>
-#include <set>
-#include <Duration.h>
-#include <timew.h>
 #include <DatetimeParser.h>
+#include <Duration.h>
+#include <Pig.h>
+#include <algorithm>
+#include <format.h>
+#include <set>
+#include <shared.h>
+#include <sstream>
+#include <timew.h>
+#include <utf8.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 A2::A2 (const std::string& raw, Lexer::Type lextype)
@@ -453,15 +452,15 @@ void CLI::canonicalizeNames ()
     else if (alreadyFoundCmd && (raw == "--help" || raw == "-h"))
     {
       for (auto& b : _args) {
-        if (b.hasTag("CMD"))
+        if (b.hasTag ("CMD"))
         {
-          b.unTag("CMD");
+          b.unTag ("CMD");
           break;
         }
       }
 
       a.tag ("CMD");
-      a.attribute("canonical", canonical);
+      a.attribute ("canonical", canonical);
     }
 
     // Hints.
@@ -523,7 +522,7 @@ void CLI::identifyFilter ()
       a.tag ("KEYWORD");
     }
 
-    else if (raw.rfind("dom.",0) == 0)
+    else if (raw.rfind ("dom.",0) == 0)
     {
       a.tag ("DOM");
     }
@@ -551,28 +550,28 @@ bool CLI::exactMatch (
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::set<int> CLI::getIds() const
+std::set <int> CLI::getIds () const
 {
   std::set <int> ids;
 
   for (auto& arg : _args)
   {
     if (arg.hasTag ("ID"))
-      ids.insert (strtol (arg.attribute ("value").c_str (), NULL, 10));
+      ids.insert (strtol (arg.attribute ("value").c_str (), nullptr, 10));
   }
 
   return ids;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::vector<std::string> CLI::getTags () const
+std::set <std::string> CLI::getTags () const
 {
-  std::vector <std::string> tags;
+  std::set <std::string> tags;
 
   for (auto& arg : _args)
   {
     if (arg.hasTag ("TAG"))
-      tags.push_back (arg.attribute ("raw"));
+      tags.insert (arg.attribute ("raw"));
   }
 
   return tags;
@@ -615,9 +614,9 @@ Duration CLI::getDuration () const
 
 std::vector <std::string> CLI::getDomReferences () const
 {
-  std::vector<std::string> references;
+  std::vector <std::string> references;
 
-  for (auto &arg : _args)
+  for (auto& arg : _args)
   {
     if (arg.hasTag ("DOM"))
     {
@@ -629,20 +628,18 @@ std::vector <std::string> CLI::getDomReferences () const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// A filter is just another interval, containing start, end and tags.
 //
-// Supported interval forms:
+// Supported range forms:
 //   ["from"] <date> ["to"|"-" <date>]
 //   ["from"] <date> "for" <duration>
 //   <duration> ["before"|"after" <date>]
 //   <duration> "ago"
 //
-Interval CLI::getFilter (const Range& default_range) const
+Range CLI::getRange (const Range& default_range) const
 {
-  // One instance, so we can directly compare.
   Datetime now;
 
-  Interval filter;
+  Range the_range;
   std::string start;
   std::string end;
   std::string duration;
@@ -667,16 +664,16 @@ Interval CLI::getFilter (const Range& default_range) const
         {
           if (range.is_empty ())
           {
-            args.emplace_back("<all>");
+            args.emplace_back ("<all>");
           }
           else
           {
             start = range.start.toISO ();
             end   = range.end.toISO ();
 
-            args.emplace_back("<date>");
-            args.emplace_back("-");
-            args.emplace_back("<date>");
+            args.emplace_back ("<date>");
+            args.emplace_back ("-");
+            args.emplace_back ("<date>");
           }
         }
 
@@ -689,14 +686,14 @@ Interval CLI::getFilter (const Range& default_range) const
         else if (end.empty ())
           end = raw;
 
-        args.emplace_back("<date>");
+        args.emplace_back ("<date>");
       }
       else if (arg._lextype == Lexer::Type::duration)
       {
         if (duration.empty ())
           duration = raw;
 
-        args.emplace_back("<duration>");
+        args.emplace_back ("<duration>");
       }
       else if (arg.hasTag ("KEYWORD"))
       {
@@ -705,37 +702,27 @@ Interval CLI::getFilter (const Range& default_range) const
         //       function.
         args.push_back (raw);
       }
-      else if (arg.hasTag ("ID"))
-      {
-        // Not part of a filter.
-      }
-      else
-      {
-        filter.tag (raw);
-      }
     }
   }
 
   if (args.empty ())
   {
-    filter.setRange(default_range);
+    the_range = default_range;
   }
-
   // <date>
   else if (args.size () == 1 &&
-      args[0] == "<date>")
+           args[0] == "<date>")
   {
     DatetimeParser dtp;
-    Range range = dtp.parse_range(start);
-    filter.setRange (range);
+    Range range = dtp.parse_range (start);
+    the_range = Range (range);
   }
-
   // from <date>
   else if (args.size () == 2 &&
            args[0] == "from" &&
            args[1] == "<date>")
   {
-    filter.setRange ({Datetime (start), 0});
+    the_range = Range {Datetime (start), 0};
   }
   // <date> to/- <date>
   else if (args.size () == 3                   &&
@@ -743,9 +730,8 @@ Interval CLI::getFilter (const Range& default_range) const
            (args[1] == "to" || args[1] == "-") &&
            args[2] == "<date>")
   {
-    filter.setRange ({Datetime (start), Datetime (end)});
+    the_range = Range {Datetime (start), Datetime (end)};
   }
-
   // from <date> to/- <date>
   else if (args.size () == 4                   &&
            args[0] == "from"                   &&
@@ -753,18 +739,16 @@ Interval CLI::getFilter (const Range& default_range) const
            (args[2] == "to" || args[2] == "-") &&
            args[3] == "<date>")
   {
-    filter.setRange ({Datetime (start), Datetime (end)});
+    the_range = Range {Datetime (start), Datetime (end)};
   }
-
   // <date> for <duration>
   else if (args.size () == 3   &&
            args[0] == "<date>" &&
            args[1] == "for"    &&
            args[2] == "<duration>")
   {
-    filter.setRange ({Datetime (start), Datetime (start) + Duration (duration).toTime_t ()});
+    the_range = Range {Datetime (start), Datetime (start) + Duration (duration).toTime_t ()};
   }
-
   // from <date> for <duration>
   else if (args.size () == 4       &&
            args[0] == "from"       &&
@@ -772,66 +756,61 @@ Interval CLI::getFilter (const Range& default_range) const
            args[2] == "for"        &&
            args[3] == "<duration>")
   {
-    filter.setRange ({Datetime (start), Datetime (start) + Duration (duration).toTime_t ()});
+    the_range = Range {Datetime (start), Datetime (start) + Duration (duration).toTime_t ()};
   }
-
   // <duration> before <date>
   else if (args.size () == 3       &&
            args[0] == "<duration>" &&
            args[1] == "before"     &&
            args[2] == "<date>")
   {
-    filter.setRange ({Datetime (start) - Duration (duration).toTime_t (), Datetime (start)});
+    the_range = Range {Datetime (start) - Duration (duration).toTime_t (), Datetime (start)};
   }
-
   // <duration> after <date>
   else if (args.size () == 3       &&
            args[0] == "<duration>" &&
            args[1] == "after"      &&
            args[2] == "<date>")
   {
-    filter.setRange ({Datetime (start), Datetime (start) + Duration (duration).toTime_t ()});
+    the_range = Range {Datetime (start), Datetime (start) + Duration (duration).toTime_t ()};
   }
-
   // <duration> ago
   else if (args.size () == 2       &&
            args[0] == "<duration>" &&
            args[1] == "ago")
   {
-    filter.setRange ({now - Duration (duration).toTime_t (), 0});
+    the_range = Range {now - Duration (duration).toTime_t (), 0};
   }
-
   // for <duration>
   else if (args.size () == 2       &&
            args[0] == "for"        &&
            args[1] == "<duration>")
   {
-    filter.setRange ({now - Duration (duration).toTime_t (), now});
+    the_range = Range {now - Duration (duration).toTime_t (), now};
   }
-
   // <duration>
   else if (args.size () == 1 &&
            args[0] == "<duration>")
   {
-    filter.setRange ({now - Duration (duration).toTime_t (), now});
+    the_range = Range {now - Duration (duration).toTime_t (), now};
   }
-
   // :all
   else if (args.size () == 1 && args[0] == "<all>")
   {
-    filter.setRange (0, 0);
+    the_range = Range (0, 0);
   }
-
-    // Unrecognized date range construct.
+  // Unrecognized date range construct.
   else if (! args.empty ())
   {
     throw std::string ("Unrecognized date range: '") + join (" ", args) + "'.";
   }
 
-  if (filter.end != 0 && filter.start > filter.end)
+  if (the_range.end != 0 && the_range.start > the_range.end)
+  {
     throw std::string ("The end of a date range must be after the start.");
+  }
 
-  return filter;
+  return the_range;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -865,7 +844,7 @@ bool CLI::getComplementaryHint (const std::string& base, const bool default_valu
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-bool CLI::getHint (const std::string &base, const bool default_value) const
+bool CLI::getHint (const std::string& base, const bool default_value) const
 {
   if (findHint (base))
   {
