@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2019 - 2021, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2019 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,54 +24,51 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <iomanip>
-#include <iostream>
-#include <shared.h>
-#include <commands.h>
-#include <Duration.h>
+#include <Chart.h>
 #include <Composite.h>
-#include <Chart.h>
-#include <format.h>
+#include <Duration.h>
 #include <cassert>
+#include <format.h>
+#include <iomanip>
+#include <shared.h>
 #include <timew.h>
-#include <Chart.h>
 #include <utf8.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 Chart::Chart (const ChartConfig& configuration) :
-  reference_datetime(configuration.reference_datetime),
-  with_label_month(configuration.with_label_month),
-  with_label_week(configuration.with_label_week),
-  with_label_weekday(configuration.with_label_weekday),
-  with_label_day(configuration.with_label_day),
-  with_ids(configuration.with_ids),
-  with_summary(configuration.with_summary),
-  with_holidays(configuration.with_holidays),
-  with_totals(configuration.with_totals),
-  with_internal_axis(configuration.with_internal_axis),
-  show_intervals(configuration.show_intervals),
-  determine_hour_range(configuration.determine_hour_range),
-  minutes_per_char(configuration.minutes_per_char),
-  spacing(configuration.spacing),
-  num_lines(configuration.num_lines),
-  color_today(configuration.color_today),
-  color_holiday(configuration.color_holiday),
-  color_label(configuration.color_label),
-  color_exclusion(configuration.color_exclusion),
-  tag_colors(configuration.tag_colors),
-  cell_width(60 / minutes_per_char + spacing),
-  reference_hour(reference_datetime.hour ())
+  reference_datetime (configuration.reference_datetime),
+  with_label_month (configuration.with_label_month),
+  with_label_week (configuration.with_label_week),
+  with_label_weekday (configuration.with_label_weekday),
+  with_label_day (configuration.with_label_day),
+  with_ids (configuration.with_ids),
+  with_summary (configuration.with_summary),
+  with_holidays (configuration.with_holidays),
+  with_totals (configuration.with_totals),
+  with_internal_axis (configuration.with_internal_axis),
+  show_intervals (configuration.show_intervals),
+  determine_hour_range (configuration.determine_hour_range),
+  minutes_per_char (configuration.minutes_per_char),
+  spacing (configuration.spacing),
+  num_lines (configuration.num_lines),
+  color_today (configuration.color_today),
+  color_holiday (configuration.color_holiday),
+  color_label (configuration.color_label),
+  color_exclusion (configuration.color_exclusion),
+  tag_colors (configuration.tag_colors),
+  cell_width (60 / minutes_per_char + spacing),
+  reference_hour (reference_datetime.hour ())
 { }
 
 std::string Chart::render (
-  const Interval &filter,
-  const std::vector<Interval> &tracked,
-  const std::vector<Range> &exclusions,
-  const std::map<Datetime, std::string> &holidays)
+  const Range& range,
+  const std::vector <Interval>& tracked,
+  const std::vector <Range>& exclusions,
+  const std::map <Datetime, std::string>& holidays)
 {
   // Determine hours shown.
   auto hour_range = determine_hour_range
-                    ? determineHourRange (filter, tracked)
+                    ? determineHourRange (range, tracked)
                     : std::make_pair (0, 23);
 
   int first_hour = hour_range.first;
@@ -89,24 +86,24 @@ std::string Chart::render (
   out << '\n';
 
   // Render the axis.
-  if (!with_internal_axis)
+  if (! with_internal_axis)
   {
     out << indent << renderAxis (first_hour, last_hour);
   }
 
   // For rendering labels on edge detection.
-  Datetime previous{0};
+  Datetime previous {0};
 
   // Each day is rendered separately.
   time_t total_work = 0;
 
-  for (Datetime day = filter.start; day < filter.end; day++)
+  for (Datetime day = range.start; day < range.end; day++)
   {
     // Render the exclusion blocks.
 
     // Add an empty string with no color, to reserve width, so this function
     // can simply concatenate to lines[i].str ().
-    std::vector<Composite> lines (num_lines);
+    std::vector <Composite> lines (num_lines);
     for (int i = 0; i < num_lines; ++i)
     {
       lines[i].add (std::string (total_width, ' '), 0, Color ());
@@ -115,9 +112,9 @@ std::string Chart::render (
     renderExclusionBlocks (lines, day, first_hour, last_hour, exclusions);
 
     time_t work = 0;
-    if (!show_intervals)
+    if (! show_intervals)
     {
-      for (auto &track : tracked)
+      for (auto& track : tracked)
       {
         time_t interval_work = 0;
         renderInterval (lines, day, track, first_hour, interval_work);
@@ -157,7 +154,7 @@ std::string Chart::render (
 
   out << (with_totals ? renderSubTotal (total_work, std::string (padding_size, ' ')) : "")
       << (with_holidays ? renderHolidays (holidays) : "")
-      << (with_summary ? renderSummary (indent, filter, exclusions, tracked) : "");
+      << (with_summary ? renderSummary (indent, range, exclusions, tracked) : "");
 
   return out.str ();
 }
@@ -174,9 +171,9 @@ unsigned long Chart::getIndentSize ()
 ////////////////////////////////////////////////////////////////////////////////
 // Scan all tracked intervals, looking for the earliest and latest hour into
 // which an interval extends.
-std::pair<int, int> Chart::determineHourRange (
-  const Interval &filter,
-  const std::vector<Interval> &tracked)
+std::pair <int, int> Chart::determineHourRange (
+  const Range& range,
+  const std::vector <Interval>& tracked)
 {
   // If there is no data, show the whole day.
   if (tracked.empty ())
@@ -188,11 +185,11 @@ std::pair<int, int> Chart::determineHourRange (
   auto first_hour = 23;
   auto last_hour = 0;
 
-  for (Datetime day = filter.start; day < filter.end; day++)
+  for (Datetime day = range.start; day < range.end; day++)
   {
     auto day_range = getFullDay (day);
 
-    for (auto &track : tracked)
+    for (auto& track : tracked)
     {
       Interval test {track};
 
@@ -210,7 +207,7 @@ std::pair<int, int> Chart::determineHourRange (
           first_hour = clipped.start.hour ();
         }
 
-        if (!clipped.is_open () && clipped.end.hour () > last_hour)
+        if (! clipped.is_open () && clipped.end.hour () > last_hour)
         {
           last_hour = clipped.end.hour ();
         }
@@ -254,7 +251,7 @@ std::string Chart::renderAxis (const int first_hour, const int last_hour)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Chart::renderMonth (const Datetime &previous, const Datetime &day)
+std::string Chart::renderMonth (const Datetime& previous, const Datetime& day)
 {
   const auto show_month = previous.month () != day.month ();
 
@@ -267,7 +264,7 @@ std::string Chart::renderMonth (const Datetime &previous, const Datetime &day)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Chart::renderWeek (const Datetime &previous, const Datetime &day)
+std::string Chart::renderWeek (const Datetime& previous, const Datetime& day)
 {
   const auto show_week = previous.week () != day.week ();
 
@@ -280,7 +277,7 @@ std::string Chart::renderWeek (const Datetime &previous, const Datetime &day)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Chart::renderWeekday (Datetime &day, const Color &color)
+std::string Chart::renderWeekday (Datetime& day, const Color& color)
 {
   std::stringstream out;
 
@@ -291,7 +288,7 @@ std::string Chart::renderWeekday (Datetime &day, const Color &color)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Chart::renderDay (Datetime &day, const Color &color)
+std::string Chart::renderDay (Datetime& day, const Color& color)
 {
   std::stringstream out;
 
@@ -303,15 +300,15 @@ std::string Chart::renderDay (Datetime &day, const Color &color)
 
 ////////////////////////////////////////////////////////////////////////////////
 Color Chart::getDayColor (
-  const Datetime &day,
-  const std::map <Datetime, std::string> &holidays)
+  const Datetime& day,
+  const std::map <Datetime, std::string>& holidays)
 {
   if (day.sameDay (reference_datetime))
   {
     return color_today;
   }
 
-  for (auto &entry : holidays)
+  for (auto& entry : holidays)
   {
     if (day.sameDay (entry.first))
     {
@@ -349,7 +346,7 @@ std::string Chart::renderTotal (time_t work)
 ////////////////////////////////////////////////////////////////////////////////
 std::string Chart::renderSubTotal (
   time_t total_work,
-  const std::string &padding)
+  const std::string& padding)
 {
   std::stringstream out;
 
@@ -369,8 +366,8 @@ std::string Chart::renderSubTotal (
 }
 
 void Chart::renderExclusionBlocks (
-  std::vector<Composite> &lines,
-  const Datetime &day,
+  std::vector <Composite>& lines,
+  const Datetime& day,
   int first_hour,
   int last_hour,
   const std::vector <Range>& exclusions)
@@ -402,7 +399,7 @@ void Chart::renderExclusionBlocks (
         int width = end_block - start_block;
         std::string block (width, ' ');
 
-        for (auto &line : lines)
+        for (auto& line : lines)
         {
           line.add (block, offset, color_exclusion);
         }
@@ -423,15 +420,15 @@ void Chart::renderExclusionBlocks (
 
 ////////////////////////////////////////////////////////////////////////////////
 void Chart::renderInterval (
-  std::vector<Composite> &lines,
-  const Datetime &day,
-  const Interval &track,
+  std::vector <Composite>& lines,
+  const Datetime& day,
+  const Interval& track,
   const int first_hour,
-  time_t &work)
+  time_t& work)
 {
   // Ignore any track that doesn't overlap with day.
   auto day_range = getFullDay (day);
-  if (!day_range.overlaps (track) || (track.is_open () && day > reference_datetime))
+  if (! day_range.overlaps (track) || (track.is_open () && day > reference_datetime))
   {
     return;
   }
@@ -479,9 +476,9 @@ void Chart::renderInterval (
       label = format ("@{1}", track.id);
     }
 
-    for (auto &tag : track.tags ())
+    for (auto& tag : track.tags ())
     {
-      if (!label.empty ())
+      if (! label.empty ())
       {
         label += ' ';
       }
@@ -493,7 +490,7 @@ void Chart::renderInterval (
 
     if (width)
     {
-      std::vector<std::string> text_lines;
+      std::vector <std::string> text_lines;
 
       // --
       // The hang/memory consumption in #309 is due to a bug in libshared's wrapText
@@ -502,7 +499,7 @@ void Chart::renderInterval (
       // but otherwise functions normally for text where the utf-8 width matches the byte length of the label.
       //
       size_t utf8_characters = utf8_text_width (label);
-      if (static_cast <size_t>(width) >= utf8_characters)
+      if (static_cast <size_t> (width) >= utf8_characters)
       {
         text_lines.push_back (label);
       }
@@ -534,11 +531,11 @@ void Chart::renderInterval (
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Chart::renderHolidays (const std::map<Datetime, std::string> &holidays)
+std::string Chart::renderHolidays (const std::map <Datetime, std::string>& holidays)
 {
   std::stringstream out;
 
-  for (auto &entry : holidays)
+  for (auto& entry : holidays)
   {
     out << entry.first.toString ("Y-M-D")
         << " "
@@ -551,31 +548,31 @@ std::string Chart::renderHolidays (const std::map<Datetime, std::string> &holida
 
 ////////////////////////////////////////////////////////////////////////////////
 std::string Chart::renderSummary (
-  const std::string &indent,
-  const Interval &filter,
-  const std::vector<Range> &exclusions,
-  const std::vector<Interval> &tracked)
+  const std::string& indent,
+  const Range& range,
+  const std::vector <Range>& exclusions,
+  const std::vector <Interval>& tracked)
 {
   std::stringstream out;
   time_t total_unavailable = 0;
 
-  for (auto &exclusion : exclusions)
+  for (auto& exclusion : exclusions)
   {
-    if (filter.overlaps (exclusion))
+    if (range.overlaps (exclusion))
     {
-      total_unavailable += filter.intersect (exclusion).total ();
+      total_unavailable += range.intersect (exclusion).total ();
     }
   }
 
   time_t total_worked = 0;
 
-  if (!show_intervals)
+  if (! show_intervals)
   {
-    for (auto &interval : tracked)
+    for (auto& interval : tracked)
     {
-      if (filter.overlaps (interval))
+      if (range.overlaps (interval))
       {
-        Interval clipped = clip (interval, filter);
+        Interval clipped = clip (interval, range);
         if (interval.is_open ())
         {
           clipped.end = reference_datetime;
@@ -586,7 +583,7 @@ std::string Chart::renderSummary (
     }
   }
 
-  auto total_available = filter.total () - total_unavailable;
+  auto total_available = range.total () - total_unavailable;
   assert (total_available >= 0);
   auto total_remaining = total_available - total_worked;
 
