@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -30,12 +30,15 @@
 #include <Range.h>
 #include <set>
 #include <string>
+#include <utility>
 
 class Interval : public Range
 {
 public:
   Interval () = default;
   Interval (const Datetime& start, const Datetime& end) : Range (start, end) {}
+  Interval (const Range& range, std::set <std::string> tags) : Range (range), _tags(std::move(tags)) {}
+
   bool operator== (const Interval&) const;
   bool operator!= (const Interval&) const;
 
@@ -43,7 +46,10 @@ public:
   bool hasTag (const std::string&) const;
   const std::set <std::string>& tags () const;
   void tag (const std::string&);
+  void tag (const std::set <std::string>&);
   void untag (const std::string&);
+  void untag (const std::set <std::string>&);
+  void clearTags ();
 
   void setRange (const Range& range);
   void setRange (const Datetime& start, const Datetime& end);
