@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2018 - 2020, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2018 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,12 +24,10 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cassert>
 #include <AtomicFile.h>
-#include <format.h>
 #include <Journal.h>
 #include <TransactionsFactory.h>
-
+#include <cassert>
 #include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -41,7 +39,7 @@ bool Journal::enabled () const
 
 ////////////////////////////////////////////////////////////////////////////////
 
-std::vector<Transaction> loadJournal (AtomicFile& undo)
+std::vector <Transaction> loadJournal (AtomicFile& undo)
 {
   std::vector <std::string> read_lines;
   undo.read (read_lines);
@@ -90,7 +88,7 @@ void Journal::startTransaction ()
 ////////////////////////////////////////////////////////////////////////////////
 void Journal::endTransaction ()
 {
-  if (!enabled ())
+  if (! enabled ())
   {
     assert (_currentTransaction == nullptr);
     return;
@@ -151,9 +149,9 @@ void Journal::recordIntervalAction (const std::string&  before, const std::strin
 // Actions are only recorded if a transaction is open
 //
 void Journal::recordUndoAction (
-  const std::string &type,
-  const std::string &before,
-  const std::string &after)
+  const std::string& type,
+  const std::string& before,
+  const std::string& after)
 {
   if (enabled () && _currentTransaction != nullptr)
   {
