@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2015 - 2016, 2018 - 2019, 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2015 - 2016, 2018 - 2019, 2022 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,12 +27,12 @@
 #ifndef INCLUDED_RULES
 #define INCLUDED_RULES
 
-#include <Lexer.h>
-#include <map>
-#include <vector>
-#include <string>
 #include <Database.h>
 #include <Journal.h>
+#include <Lexer.h>
+#include <map>
+#include <string>
+#include <vector>
 
 class Rules
 {
@@ -42,32 +42,25 @@ public:
   std::string file () const;
 
   bool        has        (const std::string&) const;
-  std::string get (const std::string &key, const std::string &defaultValue = "") const;
-  int         getInteger (const std::string&, int defaultValue = 0) const;
+  std::string get (const std::string&, const std::string& = "") const;
+  int         getInteger (const std::string&, int = 0) const;
   double      getReal    (const std::string&) const;
-  bool        getBoolean (const std::string&, bool defaultValue = false) const;
+  bool        getBoolean (const std::string&, bool = false) const;
 
-  void set (const std::string&, const int);
-  void set (const std::string&, const double);
+  void set (const std::string&, int);
+  void set (const std::string&, double);
   void set (const std::string&, const std::string&);
 
-  std::vector <std::string> all (const std::string& stem = "") const;
+  std::vector <std::string> all (const std::string& = "") const;
   bool isRuleType (const std::string&) const;
 
   std::string dump () const;
 
-  static bool setConfigVariable (Journal& journal,
-                                 const Rules& rules,
-                                 std::string name,
-                                 std::string value,
-                                 bool confirmation /* = false */);
-  static int unsetConfigVariable (Journal& journal,
-                                  const Rules& rules,
-                                  std::string name,
-                                  bool confirmation /* = false */);
+  static bool setConfigVariable (Journal&, const Rules&, std::string, std::string, bool confirmation);
+  static int unsetConfigVariable (Journal&, const Rules&, std::string, bool confirmation);
 
 private:
-  void parse               (const std::string&, int next = 1);
+  void parse               (const std::string&, int = 1);
   void parseRule           (const std::string&);
   void parseRuleSettings   (const std::vector <std::string>&);
 
