@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2021, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,20 +24,21 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <Duration.h>
-#include <Range.h>
 #include <Chart.h>
 #include <ChartConfig.h>
+#include <Duration.h>
+#include <IntervalFilterAllInRange.h>
+#include <IntervalFilterAllWithTags.h>
+#include <IntervalFilterAndGroup.h>
+#include <Range.h>
 #include <commands.h>
-#include <timew.h>
-#include <shared.h>
 #include <format.h>
 #include <iostream>
-#include <iomanip>
+#include <timew.h>
 
-int renderChart (const CLI&, const std::string&, Interval&, Rules&, Database&);
+int renderChart (const std::string&, const CLI&, Rules&, Database&);
 
-std::map <Datetime, std::string> createHolidayMap (Rules&, Interval&);
+std::map <Datetime, std::string> createHolidayMap (Rules&, Range&);
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdChartDay (
@@ -45,13 +46,7 @@ int CmdChartDay (
   Rules& rules,
   Database& database)
 {
-  Range default_range = {};
-  expandIntervalHint (rules.get ("reports.day.range", ":day"), default_range);
-
-  // Create a filter, and if empty, choose the current day.
-  auto filter = cli.getFilter (default_range);
-
-  return renderChart (cli, "day", filter, rules, database);
+  return renderChart ("day", cli, rules, database);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -60,13 +55,7 @@ int CmdChartWeek (
   Rules& rules,
   Database& database)
 {
-  Range default_range = {};
-  expandIntervalHint (rules.get ("reports.week.range", ":week"), default_range);
-
-  // Create a filter, and if empty, choose the current week.
-  auto filter = cli.getFilter (default_range);
-
-  return renderChart (cli, "week", filter, rules, database);
+  return renderChart ("week", cli, rules, database);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -75,27 +64,34 @@ int CmdChartMonth (
   Rules& rules,
   Database& database)
 {
-  Range default_range = {};
-  expandIntervalHint (rules.get ("reports.month.range", ":month"), default_range);
-
-  // Create a filter, and if empty, choose the current month.
-  auto filter = cli.getFilter (default_range);
-
-  return renderChart (cli, "month", filter, rules, database);
+  return renderChart ("month", cli, rules, database);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 int renderChart (
-  const CLI& cli,
   const std::string& type,
-  Interval& filter,
+  const CLI& cli,
   Rules& rules,
   Database& database)
 {
   const bool verbose = rules.getBoolean ("verbose");
 
+  auto default_hint = rules.get ("reports.range", type);
+  auto report_hint = rules.get ("reports." + type + ".range", default_hint);
+
+  Range default_range = {};
+  expandIntervalHint (":" + report_hint, default_range);
+
+  auto range = cli.getRange (default_range);
+  auto tags = cli.getTags ();
+
   // Load the data.
-  const auto tracked = getTracked (database, rules, filter);
+  IntervalFilterAndGroup filtering ({
+    std::make_shared <IntervalFilterAllInRange> (range),
+    std::make_shared <IntervalFilterAllWithTags> (tags)
+  });
+
+  auto tracked = getTracked (database, rules, filtering);
 
   if (tracked.empty ())
   {
@@ -103,16 +99,18 @@ int renderChart (
     {
       std::cout << "No filtered data found";
 
-      if (filter.is_started ())
+      if (range.is_started ())
       {
-        std::cout << " in the range " << filter.start.toISOLocalExtended ();
-        if (filter.is_ended ())
-          std::cout << " - " << filter.end.toISOLocalExtended ();
+        std::cout << " in the range " << range.start.toISOLocalExtended ();
+        if (range.is_ended ())
+        {
+          std::cout << " - " << range.end.toISOLocalExtended ();
+        }
       }
 
-      if (! filter.tags ().empty ())
+      if (! tags.empty ())
       {
-        std::cout << " tagged with " << joinQuotedIfNeeded (", ", filter.tags ());
+        std::cout << " tagged with " << joinQuotedIfNeeded (", ", tags);
       }
 
       std::cout << ".\n";
@@ -121,8 +119,8 @@ int renderChart (
     return 0;
   }
 
-  const auto exclusions = getAllExclusions (rules, filter);
-  const auto holidays = createHolidayMap (rules, filter);
+  const auto exclusions = getAllExclusions (rules, range);
+  const auto holidays = createHolidayMap (rules, range);
 
   // Map tags to colors.
   auto palette = createPalette (rules);
@@ -131,12 +129,16 @@ int renderChart (
   const auto minutes_per_char = rules.getInteger ("reports." + type + ".cell");
 
   if (minutes_per_char < 1)
+  {
     throw format ("The value for 'reports.{1}.cell' must be at least 1.", type);
+  }
 
   const auto num_lines = rules.getInteger ("reports." + type + ".lines", 1);
 
   if (num_lines < 1)
+  {
     throw format ("Invalid value for 'reports.{1}.lines': '{2}'", type, num_lines);
+  }
 
   ChartConfig configuration {};
   configuration.reference_datetime = Datetime ();
@@ -144,12 +146,12 @@ int renderChart (
   configuration.with_label_week = rules.getBoolean ("reports." + type + ".week");
   configuration.with_label_weekday = rules.getBoolean ("reports." + type + ".weekday");
   configuration.with_label_day = rules.getBoolean ("reports." + type + ".day");
-  configuration.with_ids = findHint (cli, ":ids");
+  configuration.with_ids = cli.getHint ("ids", false);
   configuration.with_summary = rules.getBoolean ("reports." + type + ".summary");
   configuration.with_holidays = rules.getBoolean ("reports." + type + ".holidays");
   configuration.with_totals = rules.getBoolean ("reports." + type + ".totals");
   configuration.with_internal_axis = rules.get ("reports." + type + ".axis") == "internal";
-  configuration.show_intervals = findHint (cli, ":blank");
+  configuration.show_intervals = cli.getHint ("blank", false);
   configuration.determine_hour_range = rules.get ("reports." + type + ".hours") == "auto";
   configuration.minutes_per_char = minutes_per_char;
   configuration.spacing = rules.getInteger ("reports." + type + ".spacing", 1);
@@ -162,18 +164,18 @@ int renderChart (
 
   Chart chart (configuration);
 
-  std::cout << chart.render (filter, tracked, exclusions, holidays);
+  std::cout << chart.render (range, tracked, exclusions, holidays);
 
   return 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::map <Datetime, std::string> createHolidayMap (Rules &rules, Interval &filter)
+std::map <Datetime, std::string> createHolidayMap (Rules& rules, Range& range)
 {
   std::map <Datetime, std::string> mapping;
   auto holidays = rules.all ("holidays.");
 
-  for (auto &entry : holidays)
+  for (auto& entry : holidays)
   {
     auto first_dot = entry.find ('.');
     auto last_dot = entry.rfind ('.');
@@ -184,7 +186,7 @@ std::map <Datetime, std::string> createHolidayMap (Rules &rules, Interval &filte
       std::replace (date.begin (), date.end (), '_', '-');
       Datetime holiday (date);
 
-      if (holiday >= filter.start && holiday <= filter.end)
+      if (holiday >= range.start && holiday <= range.end)
       {
         std::stringstream out;
         out << " ["
