@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,11 +24,11 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <timew.h>
+#include <IntervalFilterAllWithIds.h>
+#include <Journal.h>
 #include <format.h>
 #include <iostream>
-#include <src/Journal.h>
-#include <IntervalFilterAllWithIds.h>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdDelete (
@@ -39,8 +39,7 @@ int CmdDelete (
 {
   const bool verbose = rules.getBoolean ("verbose");
 
-  // Gather IDs.
-  std::set <int> ids = cli.getIds ();
+  auto ids = cli.getIds ();
 
   if (ids.empty ())
   {
@@ -53,7 +52,6 @@ int CmdDelete (
   auto filtering = IntervalFilterAllWithIds (ids);
   auto intervals = getTracked (database, rules, filtering);
 
-
   if (intervals.size () != ids.size ())
   {
     for (auto& id: ids)
@@ -68,7 +66,7 @@ int CmdDelete (
           break;
         }
       }
-      if (!found)
+      if (! found)
       {
         throw format ("ID '@{1}' does not correspond to any tracking.", id);
       }
