@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2021, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,9 +24,13 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
+#include <IntervalFilterAllInRange.h>
+#include <IntervalFilterAllWithIds.h>
+#include <IntervalFilterAllWithTags.h>
+#include <IntervalFilterAndGroup.h>
 #include <commands.h>
-#include <timew.h>
 #include <iostream>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdExport (
@@ -34,8 +38,37 @@ int CmdExport (
   Rules& rules,
   Database& database)
 {
-  auto filter = cli.getFilter ();
-  std::cout << jsonFromIntervals (getTracked (database, rules, filter));
+  auto ids = cli.getIds ();
+  auto range = cli.getRange ();
+  auto tags = cli.getTags ();
+
+  std::shared_ptr <IntervalFilter> filtering;
+
+  if (! ids.empty ())
+  {
+    if (! range.is_empty ())
+    {
+      throw std::string ("You cannot specify both id and tags/range to export intervals.");
+    }
+
+    filtering = std::make_shared <IntervalFilterAllWithIds> (ids);
+  }
+  else
+  {
+    filtering = std::make_shared <IntervalFilterAndGroup> (
+      std::vector <std::shared_ptr <IntervalFilter>> (
+        {
+          std::make_shared <IntervalFilterAllInRange> (range),
+          std::make_shared <IntervalFilterAllWithTags> (tags),
+        }
+      )
+    );
+  }
+
+  auto intervals = getTracked (database, rules, *filtering);
+
+  std::cout << jsonFromIntervals (intervals);
+
   return 0;
 }
 
