@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2020, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,10 +25,10 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <commands.h>
-#include <timew.h>
-#include <shared.h>
 #include <format.h>
 #include <iostream>
+#include <shared.h>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 // Іdentify DOM references in cli, provide space-separated results.
@@ -37,20 +37,25 @@ int CmdGet (
   Rules& rules,
   Database& database)
 {
+  auto references = cli.getDomReferences ();
+  auto filter = Interval {cli.getRange (), cli.getTags ()};
+
   std::vector <std::string> results;
-  std::vector <std::string> references = cli.getDomReferences ();
-  Interval filter = cli.getFilter ();
 
   for (auto& reference : references)
   {
     std::string value;
+
     if (! domGet (database, filter, rules, reference, value))
+    {
       throw format ("DOM reference '{1}' is not valid.", reference);
+    }
 
     results.push_back (value);
   }
 
   std::cout << join (" ", results) << '\n';
+
   return 0;
 }
 
