@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,14 +24,12 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Duration.h>
-#include <format.h>
-#include <commands.h>
-#include <timew.h>
-#include <iostream>
-#include <stdlib.h>
 #include <IntervalFilterAllWithIds.h>
+#include <commands.h>
+#include <format.h>
+#include <iostream>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdLengthen (
@@ -42,15 +40,14 @@ int CmdLengthen (
 {
   const bool verbose = rules.getBoolean ("verbose");
 
-  // Gather IDs and TAGs.
-  std::set <int> ids = cli.getIds ();
+  auto ids = cli.getIds ();
 
   if (ids.empty ())
   {
     throw std::string ("IDs must be specified. See 'timew help lengthen'.");
   }
 
-  Duration dur = cli.getDuration ();
+  auto dur = cli.getDuration ();
 
   journal.startTransaction ();
 
@@ -72,7 +69,7 @@ int CmdLengthen (
           break;
         }
       }
-      if (!found)
+      if (! found)
       {
         throw format ("ID '@{1}' does not correspond to any tracking.", id);
       }
