@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2021, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,16 +24,17 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
-#include <commands.h>
-#include <timew.h>
-#include <Table.h>
 #include <Color.h>
-#include <set>
-#include <iostream>
 #include <IntervalFilterAllInRange.h>
 #include <IntervalFilterAllWithTags.h>
 #include <IntervalFilterAndGroup.h>
+#include <Table.h>
+#include <TagDescription.h>
+#include <TagsTable.h>
+#include <commands.h>
+#include <iostream>
+#include <set>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdTags (
@@ -43,46 +44,47 @@ int CmdTags (
 {
   const bool verbose = rules.getBoolean ("verbose");
 
-  // Create a filter, with no default range.
-  auto filter = cli.getFilter ();
   IntervalFilterAndGroup filtering ({
-    std::make_shared <IntervalFilterAllInRange> ( Range { filter.start, filter.end }),
-    std::make_shared <IntervalFilterAllWithTags> (filter.tags ())
+    std::make_shared <IntervalFilterAllInRange> (cli.getRange ()),
+    std::make_shared <IntervalFilterAllWithTags> (cli.getTags ())
   });
 
   // Generate a unique, ordered list of tags.
   std::set <std::string> tags;
+
   for (const auto& interval : getTracked (database, rules, filtering))
-    for (auto& tag : interval.tags ())
+  {
+    for (const auto& tag : interval.tags ())
+    {
       tags.insert (tag);
+    }
+  }
 
   // Shows all tags.
-  if (! tags.empty ())
+  if (tags.empty ())
   {
-    Table t;
-    t.width (1024);
-    t.colorHeader (Color ("underline"));
-    t.add ("Tag");
-    t.add ("Description");
-    // TODO Show all tag metadata.
-
-    for (auto& tag : tags)
+    if (verbose)
     {
-      auto row = t.addRow ();
-      t.set (row, 0, tag, tagColor (rules, tag));
-
-      auto name = std::string ("tags.") + tag + ".description";
-      t.set (row, 1, rules.has (name) ? rules.get (name) : "-");
+      std::cout << "No data found.\n";
     }
-
-    std::cout << '\n'
-              << t.render ()
-              << '\n';
   }
   else
   {
-    if (verbose)
-      std::cout << "No data found.\n";
+    std::vector <TagDescription> tagDescriptions;
+
+    for (const auto& tag: tags)
+    {
+      auto name = std::string ("tags.") + tag + ".description";
+      tagDescriptions.emplace_back (tag, tagColor (rules, tag), rules.has (name) ? rules.get (name) : "-");
+    }
+
+    auto table = TagsTable::builder()
+      .withTagDescriptions (tagDescriptions)
+      .build ();
+
+    std::cout << '\n'
+              << table.render ()
+              << '\n';
   }
 
   return 0;
