@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,15 +24,13 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
+#include <IntervalFilterAllInRange.h>
+#include <IntervalFilterAllWithIds.h>
+#include <IntervalFilterFirstOf.h>
 #include <commands.h>
 #include <format.h>
-#include <timew.h>
 #include <iostream>
-#include <stdlib.h>
-#include <IntervalFilterAllWithIds.h>
-#include <IntervalFilterAllInRange.h>
-#include <IntervalFilterFirstOf.h>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdUntag (
@@ -45,7 +43,7 @@ int CmdUntag (
 
   // Gather IDs and TAGs.
   std::set <int> ids = cli.getIds ();
-  std::vector<std::string> tags = cli.getTags ();
+  std::set <std::string> tags = cli.getTags ();
 
   if (tags.empty ())
   {
@@ -66,7 +64,7 @@ int CmdUntag (
     {
       throw std::string ("There is no active time tracking.");
     }
-    else if (!latest.at (0).is_open ())
+    else if (! latest.at (0).is_open ())
     {
       throw std::string ("At least one ID must be specified. See 'timew help untag'.");
     }
@@ -92,7 +90,7 @@ int CmdUntag (
             break;
           }
         }
-        if (!found)
+        if (! found)
         {
           throw format ("ID '@{1}' does not correspond to any tracking.", id);
         }
@@ -105,10 +103,7 @@ int CmdUntag (
   {
     Interval modified {interval};
 
-    for (auto& tag : tags)
-    {
-      modified.untag (tag);
-    }
+    modified.untag (tags);
 
     database.modifyInterval (interval, modified, verbose);
 
