@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2018, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,13 +24,11 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Color.h>
-#include <sstream>
-#include <vector>
 #include <cstdlib>
-#include <shared.h>
 #include <format.h>
+#include <shared.h>
+#include <sstream>
 
 // uint to string lookup table for Color::_colorize()
 // _colorize() gets called _a lot_, having this lookup table is a cheap
@@ -93,12 +91,6 @@ Color::Color ()
 {
 }
 
-////////////////////////////////////////////////////////////////////////////////
-Color::Color (const Color& other)
-{
-  _value = other._value;
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 Color::Color (unsigned int c)
 : _value (0)
@@ -241,7 +233,7 @@ Color::Color (const std::string& spec)
         fg_value |= _COLOR_256;
       }
     }
-    else if (word != "")
+    else if (!word.empty ())
       throw format ("The color '{1}' is not recognized.", word);
   }
 
@@ -282,6 +274,12 @@ Color::Color (color_id fg, color_id bg, bool underline, bool bold, bool bright)
   }
 }
 
+////////////////////////////////////////////////////////////////////////////////
+bool Color::operator== (const Color& other) const
+{
+  return int(_value) == int(other);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 Color::operator std::string () const
 {
@@ -321,7 +319,7 @@ Color::operator int () const
 // other take precedence.
 void Color::blend (const Color& other)
 {
-  if (!other.nontrivial ())
+  if (!other.nontrivial () || (*this) == other)
     return;
 
   Color c (other);
@@ -618,7 +616,7 @@ std::string Color::end () const
 ////////////////////////////////////////////////////////////////////////////////
 bool Color::nontrivial () const
 {
-  return _value != 0 ? true : false;
+  return _value != 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
