@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2019, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -45,7 +45,8 @@ public:
   enum color_id {nocolor = 0, black, red, green, yellow, blue, magenta, cyan, white};
 
   Color ();
-  Color (const Color&);
+  Color (const Color&) = default;
+  Color& operator= (const Color&) = default;
   Color (unsigned int);                         // 256 | INVERSE | UNDERLINE | BOLD | BRIGHT | (BG << 8) | FG
   Color (const std::string&);                   // "red on bright black"
   Color (color_id);                             // fg.
@@ -65,6 +66,7 @@ public:
   std::string end () const;
 
   bool nontrivial () const;
+  bool operator== (const Color&) const;
 
 private:
   int find (const std::string&);
