@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2015 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,11 +24,10 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Composite.h>
-#include <utf8.h>
 #include <sstream>
 #include <stack>
+#include <utf8.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 // Initially assume no text, but infinite virtual space.
@@ -51,7 +50,7 @@ void Composite::add (
   std::string::size_type offset,
   const Color& color)
 {
-  _layers.push_back (std::make_tuple (text, offset, color));
+  _layers.emplace_back (text, offset, color);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -85,7 +84,7 @@ std::string Composite::str () const
   std::vector <int> colors;
   for (unsigned int layer = 0; layer < _layers.size (); ++layer)
   {
-    auto text   = std::get <0> (_layers[layer]);
+    const auto& text   = std::get <0> (_layers[layer]);
     auto offset = std::get <1> (_layers[layer]);
     auto len    = utf8_text_length (text);
 
