@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,29 +27,33 @@
 #ifndef INCLUDED_CONFIGURATION
 #define INCLUDED_CONFIGURATION
 
-#include <map>
-#include <vector>
-#include <string>
 #include <FS.h>
+#include <map>
+#include <string>
+#include <vector>
 
 bool setVariableInFile   (const std::string&, const std::string&, const std::string&);
 bool unsetVariableInFile (const std::string&, const std::string&);
 
-// ct.cpp
-std::vector <std::tuple <std::string, int>> foo (File&);
-
 class Configuration : public std::map <std::string, std::string>
 {
 public:
-  void load  (const std::string&, int nest = 1);
+  void load (
+      const std::string& file_path,
+      int nest = 1,
+      const std::vector <std::string>& search_paths = {});
   void save ();
-  void parse (const std::string&, int nest = 1);
+  void parse (
+    const std::string& content,
+    int nest = 1,
+    const std::vector <std::string>& search_paths = {},
+    const std::string& file_path = {});
 
-  bool        has        (const std::string&) const;
-  std::string get        (const std::string&) const;
-  int         getInteger (const std::string&) const;
-  double      getReal    (const std::string&) const;
-  bool        getBoolean (const std::string&) const;
+  bool        has            (const std::string&) const;
+  std::string get            (const std::string&, bool getFromContext = true) const;
+  int         getInteger     (const std::string&, bool getFromContext = true) const;
+  double      getReal        (const std::string&, bool getFromContext = true) const;
+  bool        getBoolean     (const std::string&, bool getFromContext = true) const;
 
   void set (const std::string&, const int);
   void set (const std::string&, const double);
