@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,16 +24,15 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Datetime.h>
 #include <algorithm>
-#include <iostream>
-#include <sstream>
-#include <iomanip>
 #include <cassert>
-#include <stdlib.h>
-#include <shared.h>
+#include <cstdlib>
 #include <format.h>
+#include <iomanip>
+#include <iostream>
+#include <shared.h>
+#include <sstream>
 #include <unicode.h>
 #include <utf8.h>
 
@@ -189,9 +188,9 @@ bool Datetime::parse (
                                             parse_time_utc_ext  (pig)  ||
                                             parse_time_utc      (pig)  ||
                                             parse_time_off_ext  (pig)  ||
-                                            parse_time_off      (pig)  ||
                                             parse_time_ext      (pig)  ||
-        (Datetime::standaloneTimeEnabled && parse_time          (pig)) // Time last, as it is the most permissive.
+        (Datetime::standaloneTimeEnabled && parse_time          (pig)) || // Time last, as it is the most permissive.
+        (Datetime::standaloneTimeEnabled && parse_time_off      (pig))
        )
       )
      )
@@ -236,7 +235,7 @@ void Datetime::clear ()
 bool Datetime::parse_formatted (Pig& pig, const std::string& format)
 {
   // Short-circuit on missing format.
-  if (format == "")
+  if (format.empty ())
     return false;
 
   auto checkpoint = pig.cursor ();
@@ -567,39 +566,39 @@ bool Datetime::parse_formatted (Pig& pig, const std::string& format)
 //   sopd           2017-03-04T00:00:00  Unaffected
 //   sod            2017-03-05T00:00:00  Unaffected
 //   sond           2017-03-06T00:00:00  Unaffected
-//   eopd           2017-03-05T00:00:00  Unaffected
-//   eod            2017-03-06T00:00:00  Unaffected
-//   eond           2017-03-07T00:00:00  Unaffected
+//   eopd           2017-03-04T23:59:59  Unaffected
+//   eod            2017-03-05T23:59:59  Unaffected
+//   eond           2017-03-06T23:59:59  Unaffected
 //   sopw           2017-02-26T00:00:00  Unaffected
 //   sow            2017-03-05T00:00:00  Unaffected
 //   sonw           2017-03-12T00:00:00  Unaffected
-//   eopw           2017-03-05T00:00:00  Unaffected
-//   eow            2017-03-12T00:00:00  Unaffected
-//   eonw           2017-03-19T00:00:00  Unaffected
+//   eopw           2017-02-26T23:59:59  Unaffected
+//   eow            2017-03-05T23:59:59  Unaffected
+//   eonw           2017-03-12T23:59:59  Unaffected
 //   sopww          2017-02-27T00:00:00  Unaffected
 //   soww           2017-03-06T00:00:00
 //   sonww          2017-03-06T00:00:00  Unaffected
-//   eopww          2017-03-03T00:00:00  Unaffected
-//   eoww           2017-03-10T00:00:00
-//   eonww          2017-03-17T00:00:00  Unaffected
+//   eopww          2017-03-03T23:59:59  Unaffected
+//   eoww           2017-03-10T23:59:59
+//   eonww          2017-03-17T23:59:59  Unaffected
 //   sopm           2017-02-01T00:00:00  Unaffected
 //   som            2017-03-01T00:00:00  Unaffected
 //   sonm           2017-04-01T00:00:00  Unaffected
-//   eopm           2017-03-01T00:00:00  Unaffected
-//   eom            2017-04-01T00:00:00  Unaffected
-//   eonm           2017-05-01T00:00:00  Unaffected
+//   eopm           2017-02-28T23:59:59  Unaffected
+//   eom            2017-03-31T23:59:59  Unaffected
+//   eonm           2017-04-30T23:59:59  Unaffected
 //   sopq           2017-10-01T00:00:00  Unaffected
 //   soq            2017-01-01T00:00:00  Unaffected
 //   sonq           2017-04-01T00:00:00  Unaffected
-//   eopq           2017-01-01T00:00:00  Unaffected
-//   eoq            2017-04-01T00:00:00  Unaffected
-//   eonq           2017-07-01T00:00:00  Unaffected
+//   eopq           2016-12-31T23:59:59  Unaffected
+//   eoq            2017-03-31T23:59:59  Unaffected
+//   eonq           2017-06-30T23:59:59  Unaffected
 //   sopy           2016-01-01T00:00:00  Unaffected
 //   soy            2017-01-01T00:00:00  Unaffected
 //   sony           2018-01-01T00:00:00  Unaffected
-//   eopy           2017-01-01T00:00:00  Unaffected
-//   eoy            2018-01-01T00:00:00  Unaffected
-//   eony           2020-01-01T00:00:00  Unaffected
+//   eopy           2016-12-31T23:59:59  Unaffected
+//   eoy            2017-12-31T23:59:59  Unaffected
+//   eony           2018-12-31T23:59:59  Unaffected
 //   easter         2017-04-16T00:00:00
 //   eastermonday   2017-04-16T00:00:00
 //   ascension      2017-05-25T00:00:00
@@ -614,7 +613,7 @@ bool Datetime::parse_named (Pig& pig)
   auto checkpoint = pig.cursor ();
 
   // Experimental handling of date phrases, such as "first monday in march".
-  // Note that this requires that phrases are deliminted by EOS or WS.
+  // Note that this requires that phrases are delimited by EOS or WS.
   std::string token;
   std::vector <std::string> tokens;
   while (pig.getUntilWS (token))
@@ -1041,7 +1040,7 @@ bool Datetime::parse_time_utc (Pig& pig)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// <time> <off>
+// <time><off>
 bool Datetime::parse_time_off (Pig& pig)
 {
   auto checkpoint = pig.cursor ();
@@ -1505,7 +1504,7 @@ bool Datetime::initializeDayName (Pig& pig)
   std::string token;
   for (int day = 0; day <= 7; ++day)   // Deliberate <= so that 'sunday' is either 0 or 7.
   {
-    if (pig.skipPartial (dayNames[day % 7], token) &&
+    if (pig.skipPartial (dayNames[day % 7], token, true) &&
         token.length () >= static_cast <std::string::size_type> (Datetime::minimumMatchLength))
     {
       auto following = pig.peek ();
@@ -1548,7 +1547,7 @@ bool Datetime::initializeMonthName (Pig& pig)
   std::string token;
   for (int month = 0; month < 12; ++month)
   {
-    if (pig.skipPartial (monthNames[month], token) &&
+    if (pig.skipPartial (monthNames[month], token, true) &&
         token.length () >= static_cast <std::string::size_type> (Datetime::minimumMatchLength))
     {
       auto following = pig.peek ();
@@ -1712,7 +1711,8 @@ bool Datetime::initializeEopd (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -1739,7 +1739,8 @@ bool Datetime::initializeEod (Pig& pig)
       struct tm* t = localtime (&now);
 
       t->tm_mday++;
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -1766,7 +1767,8 @@ bool Datetime::initializeEond (Pig& pig)
       struct tm* t = localtime (&now);
 
       t->tm_mday += 2;
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -1880,7 +1882,8 @@ bool Datetime::initializeEopw (Pig& pig)
     {
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
 
       int extra = (t->tm_wday + 6) % 7;
       t->tm_mday -= extra;
@@ -1909,7 +1912,8 @@ bool Datetime::initializeEow (Pig& pig)
     {
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
 
       int extra = (t->tm_wday + 6) % 7;
       t->tm_mday -= extra;
@@ -1939,9 +1943,12 @@ bool Datetime::initializeEonw (Pig& pig)
     {
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
+
+      int extra = (t->tm_wday + 6) % 7;
+      t->tm_mday += 14 - extra;
 
-      t->tm_mday += 15 - t->tm_wday;
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -1994,7 +2001,7 @@ bool Datetime::initializeSoww (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_mday += 8 - t->tm_wday;
+      t->tm_mday += 1 - t->tm_wday;
       t->tm_hour = t->tm_min = t->tm_sec = 0;
       t->tm_isdst = -1;
       _date = mktime (t);
@@ -2048,8 +2055,9 @@ bool Datetime::initializeEopww (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_mday -= (t->tm_wday + 1) % 7;
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_mday -= t->tm_wday + 1;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -2076,7 +2084,8 @@ bool Datetime::initializeEoww (Pig& pig)
       struct tm* t = localtime (&now);
 
       t->tm_mday += 6 - t->tm_wday;
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -2103,7 +2112,8 @@ bool Datetime::initializeEonww (Pig& pig)
       struct tm* t = localtime (&now);
 
       t->tm_mday += 13 - t->tm_wday;
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_isdst = -1;
       _date = mktime (t);
       return true;
@@ -2227,7 +2237,8 @@ bool Datetime::initializeEopm (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mday = 1;
       t->tm_isdst = -1;
       _date = mktime (t);
@@ -2254,7 +2265,8 @@ bool Datetime::initializeEom (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
 
       t->tm_mon++;
       if (t->tm_mon > 11)
@@ -2289,7 +2301,8 @@ bool Datetime::initializeEonm (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mday = 1;
       t->tm_mon += 2;
       if (t->tm_mon > 11)
@@ -2420,7 +2433,8 @@ bool Datetime::initializeEopq (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mon -= t->tm_mon % 3;
       t->tm_mday = 1;
       t->tm_isdst = -1;
@@ -2455,7 +2469,8 @@ bool Datetime::initializeEoq (Pig& pig)
         ++t->tm_year;
       }
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mday = 1;
       t->tm_isdst = -1;
       _date = mktime (t);
@@ -2482,7 +2497,8 @@ bool Datetime::initializeEonq (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mon += 6 - (t->tm_mon % 3);
       if (t->tm_mon > 11)
       {
@@ -2602,7 +2618,8 @@ bool Datetime::initializeEopy (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mon = 0;
       t->tm_mday = 1;
       t->tm_isdst = -1;
@@ -2630,7 +2647,8 @@ bool Datetime::initializeEoy (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mon = 0;
       t->tm_mday = 1;
       t->tm_year++;
@@ -2659,7 +2677,8 @@ bool Datetime::initializeEony (Pig& pig)
       time_t now = time (nullptr);
       struct tm* t = localtime (&now);
 
-      t->tm_hour = t->tm_min = t->tm_sec = 0;
+      t->tm_hour = t->tm_min = 0;
+      t->tm_sec = -1;
       t->tm_mon = 0;
       t->tm_mday = 1;
       t->tm_year += 2;
@@ -3100,7 +3119,7 @@ bool Datetime::validate ()
 // int tm_year;      year - 1900
 // int tm_wday;      day of week (Sunday = 0)
 // int tm_yday;      day of year (0 - 365)
-// int tm_isdst;     is summer time in effect?
+// int tm_isdst;     is daylight saving time in effect?
 // char *tm_zone;    abbreviation of timezone name
 // long tm_gmtoff;   offset from UTC in seconds
 void Datetime::resolve ()
@@ -3278,7 +3297,7 @@ void Datetime::toYMD (int& y, int& m, int& d) const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Datetime::toString (const std::string& format) const
+std::string Datetime::toString (const std::string& format) const
 {
   std::stringstream formatted;
   for (unsigned int i = 0; i < format.length (); ++i)
@@ -3317,7 +3336,7 @@ const std::string Datetime::toString (const std::string& format) const
 ////////////////////////////////////////////////////////////////////////////////
 Datetime Datetime::startOfDay () const
 {
-  return Datetime (year (), month (), day ());
+  return { year (), month (), day () };
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -3325,19 +3344,19 @@ Datetime Datetime::startOfWeek () const
 {
   Datetime sow (_date);
   sow -= (dayOfWeek () * 86400);
-  return Datetime (sow.year (), sow.month (), sow.day ());
+  return { sow.year (), sow.month (), sow.day () };
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Datetime Datetime::startOfMonth () const
 {
-  return Datetime (year (), month (), 1);
+  return { year (), month (), 1 };
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Datetime Datetime::startOfYear () const
 {
-  return Datetime (year (), 1, 1);
+  return { year (), 1, 1 };
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -3390,7 +3409,7 @@ bool Datetime::valid (const int y, const int m, const int d)
     return false;
 
   // Finally check that the days fall within the acceptable range for this
-  // month, and whether or not this is a leap year.
+  // month, and whether this is a leap year.
   if (d < 1 || d > Datetime::daysInMonth (y, m))
     return false;
 
@@ -3714,13 +3733,13 @@ bool Datetime::sameYear (const Datetime& rhs) const
 ////////////////////////////////////////////////////////////////////////////////
 Datetime Datetime::operator+ (const int delta)
 {
-  return Datetime (_date + delta);
+  return { _date + delta };
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Datetime Datetime::operator- (const int delta)
 {
-  return Datetime (_date - delta);
+  return { _date - delta };
 }
 
 ////////////////////////////////////////////////////////////////////////////////
