@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2019, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -28,8 +28,8 @@
 #define INCLUDED_DURATION
 
 #include <Pig.h>
+#include <ctime>
 #include <string>
-#include <time.h>
 
 class Duration
 {
@@ -50,15 +50,15 @@ public:
   bool parse_designated (Pig&);
   bool parse_weeks (Pig&);
   bool parse_units (Pig&);
-  const std::string format () const;
-  const std::string formatHours () const;
-  const std::string formatISO () const;
-  const std::string formatVague (bool padding = false) const;
+  std::string format () const;
+  std::string formatHours () const;
+  std::string formatISO () const;
+  std::string formatVague (bool padding = false) const;
 
   int days () const;
   int hours () const;
   int minutes () const;
-  int seconds () const;
+  time_t seconds () const;
 
 private:
   void clear ();
@@ -66,14 +66,14 @@ private:
   std::string dump () const;
 
 public:
-  int _year      {0};
-  int _month     {0};
-  int _weeks     {0};
-  int _day       {0};
-  int _hours     {0};
-  int _minutes   {0};
-  int _seconds   {0};
-  time_t _period {0};
+  int _year       {0};
+  int _month      {0};
+  int _weeks      {0};
+  int _day        {0};
+  int _hours      {0};
+  int _minutes    {0};
+  time_t _seconds {0};
+  time_t _period  {0};
 };
 
 #endif
