@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,24 +25,27 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+// Needed for Cygwin compatibility (see #2632)
+#if defined CYGWIN
+#define _GNU_SOURCE
+#endif
 #include <FS.h>
+#include <cerrno>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <dirent.h>
+#include <fcntl.h>
+#include <format.h>
 #include <fstream>
 #include <glob.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <stdlib.h>
 #include <pwd.h>
-#include <cstdio>
+#include <string>
+#include <sys/stat.h>
 #include <unistd.h>
-#include <fcntl.h>
-#include <dirent.h>
-#include <errno.h>
-#include <string.h>
-#include <shared.h>
-#include <format.h>
 
 #if defined SOLARIS || defined NETBSD || defined FREEBSD || defined DRAGONFLY || !defined(__GLIBC__)
-#include <limits.h>
+#include <climits>
 #endif
 
 #if defined __APPLE__
@@ -59,9 +62,7 @@
 #endif
 
 ////////////////////////////////////////////////////////////////////////////////
-Path::Path ()
-{
-}
+Path::Path () = default;
 
 ////////////////////////////////////////////////////////////////////////////////
 Path::Path (const Path& other)
@@ -114,7 +115,7 @@ Path::operator std::string () const
 ////////////////////////////////////////////////////////////////////////////////
 std::string Path::name () const
 {
-  if (_data.length ())
+  if (!_data.empty ())
   {
     auto slash = _data.rfind ('/');
     if (slash != std::string::npos)
@@ -127,11 +128,12 @@ std::string Path::name () const
 ////////////////////////////////////////////////////////////////////////////////
 std::string Path::parent () const
 {
-  if (_data.length ())
+  if (!_data.empty ())
   {
     auto slash = _data.rfind ('/');
     if (slash != std::string::npos)
       return _data.substr (0, slash);
+    return ".";
   }
 
   return "";
@@ -140,7 +142,7 @@ std::string Path::parent () const
 ////////////////////////////////////////////////////////////////////////////////
 std::string Path::extension () const
 {
-  if (_data.length ())
+  if (!_data.empty ())
   {
     auto dot = _data.rfind ('.');
     if (dot != std::string::npos)
@@ -150,10 +152,25 @@ std::string Path::extension () const
   return "";
 }
 
+////////////////////////////////////////////////////////////////////////////////
+std::string Path::realpath () const
+{
+  if (_data.empty ())
+    return "";
+
+  char *result_c = ::realpath (_data.c_str(), nullptr);
+  if (result_c == nullptr)
+    return "";
+
+  std::string result (result_c);
+  free(result_c);
+  return result;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 bool Path::exists () const
 {
-  return access (_data.c_str (), F_OK) ? false : true;
+  return access (_data.c_str (), F_OK) == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -174,7 +191,7 @@ bool Path::is_directory () const
 ////////////////////////////////////////////////////////////////////////////////
 bool Path::is_absolute () const
 {
-  if (_data.length () && _data[0] == '/')
+  if (!_data.empty () && _data[0] == '/')
     return true;
 
   return false;
@@ -205,7 +222,7 @@ bool Path::readable () const
   if (status == -1 && errno != EACCES)
     throw format ("access error {1}: {2}", errno, strerror (errno));
 
-  return status ? false : true;
+  return status == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -220,7 +237,7 @@ bool Path::writable () const
   if (status == -1 && errno != EACCES)
     throw format ("access error {1}: {2}", errno, strerror (errno));
 
-  return status ? false : true;
+  return status == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -235,7 +252,7 @@ bool Path::executable () const
   if (status == -1 && errno != EACCES)
     throw format ("access error {1}: {2}", errno, strerror (errno));
 
-  return status ? false : true;
+  return status == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -255,65 +272,81 @@ bool Path::rename (const std::string& new_name)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// ~      --> /home/user
-// ~foo/x --> /home/foo/s
-// ~/x    --> /home/foo/x
-// .      --> $PWD
-// ./x    --> $PWD/x
-// x      --> $PWD/x
+// Supported expansion:
+// - tilde       `~`    -> home directory of current user
+// - tilde       `~foo` -> home directory of user `foo`
+// - environment `$FOO` -> value of environment variable `FOO`
+//
+// Relative path is kept relative here.
+//
+// ~        --> /home/user
+// ~foo/x   --> /home/foo/s
+// ~/x      --> /home/foo/x
+// $HOME/x  --> /home/foo/x
+// ./$FOO/x --> ./<value of FOO>/x
+// ./x      --> ./x
 std::string Path::expand (const std::string& in)
 {
-  std::string copy = in;
-
-  std::string::size_type slash;
-
-  if (in.empty ())
-  { }
-
-  else if (in.front () == '~')
+  std::string result;
+  for (size_t i = 0; i < in.length (); ++i)
   {
-    const char* home = getenv ("HOME");
-    if (home == nullptr)
+    // Expand `~` only at start.
+    if (i == 0 && in.at (0) == '~')
     {
-      struct passwd* pw = getpwuid (getuid ());
-      home = pw->pw_dir;
+      auto slash = in.find ('/', 1);
+      if (slash == std::string::npos)
+        slash = in.length ();
+
+      // Convert: ~ --> /home/user
+      if (slash == 1)
+      {
+        const char* home = getenv ("HOME");
+        if (home == nullptr)
+        {
+          struct passwd* pw = getpwuid (getuid ());
+          home = pw->pw_dir;
+        }
+        result += home;
+      }
+      // Convert: ~name --> /home/name
+      else
+      {
+        std::string name = in.substr (1, slash - 1);
+        struct passwd* pw = getpwnam (name.c_str ());
+        if (pw)
+          result += pw->pw_dir;
+        else
+          result += "/home/" + name;
+      }
+
+      // Process `/` in the next loop.
+      i = slash - 1;
     }
 
-    // Convert: ~ --> /home/user
-    if (in.length () == 1)
-      copy = home;
-
-    // Convert: ~/x --> /home/user/x
-    else if (in.at (1) == '/')
-      copy = home + in.substr (1);
-
-    // Convert: ~foo/x --> /home/foo/x
-    else if ((slash = in.find ('/', 1)) != std::string::npos)
+    // Expand environment variable.
+    else if (in.at (i) == '$')
     {
-      std::string name = in.substr (1, slash - 1);
-      struct passwd* pw = getpwnam (name.c_str ());
-      if (pw)
-        copy = pw->pw_dir + in.substr (slash);
+      size_t end = i + 1;
+      while (end < in.length () && (isalnum(in.at (end)) || in.at (end) == '_'))
+        ++end;
+      if (i + 1 == end)
+        result += "$";
+      else
+      {
+        std::string name = in.substr (i + 1, end - (i + 1));
+        const char *value = getenv (name.c_str ());
+        if (value != nullptr)
+          result += value;
+      }
+      i = end - 1;
     }
-  }
 
-  // Relative paths
-  else if (in.front () != '/')
-  {
-    // Convert: ., ./ --> $PWD
-    if (in == ".")
-      copy = Directory::cwd ();
-
-    // Convert: ./x --> $PWD/x
-    else if (in.substr (0, 2) == "./")
-      copy = Directory::cwd () + in.substr (1);
-
-    // Convert: x --> $PWD/x
+    // Otherwise, keep the char.
     else
-      copy = Directory::cwd () + '/' + in;
+      result += in.at (i);
   }
 
-  return copy;
+  return result;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -328,7 +361,7 @@ std::vector <std::string> Path::glob (const std::string& pattern)
   if (!::glob (pattern.c_str (), GLOB_ERR | GLOB_BRACE | GLOB_TILDE, nullptr, &g))
 #endif
     for (int i = 0; i < (int) g.gl_pathc; ++i)
-      results.push_back (g.gl_pathv[i]);
+      results.emplace_back (g.gl_pathv[i]);
 
   globfree (&g);
   return results;
@@ -409,7 +442,7 @@ bool File::create (int mode /* = 0640 */)
 ////////////////////////////////////////////////////////////////////////////////
 bool File::remove () const
 {
-  return unlink (_data.c_str ()) == 0 ? true : false;
+  return unlink (_data.c_str ()) == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -426,7 +459,7 @@ std::string File::removeBOM (const std::string& input)
 ////////////////////////////////////////////////////////////////////////////////
 bool File::open ()
 {
-  if (_data != "")
+  if (!_data.empty ())
   {
     if (! _fh)
     {
@@ -460,6 +493,26 @@ void File::close ()
     if (_locked)
       unlock ();
 
+    // fdatasync() is faster we can't trust it anywhere but Linux.
+    // https://news.ycombinator.com/item?id=25171572
+    #if defined (LINUX)
+      if (fdatasync (fileno (_fh)))
+        throw format ("fdatasync error {1}: {2}", errno, strerror (errno));
+    #elif defined (DARWIN)
+      // https://developer.apple.com/library/archive/documentation/System/Conceptual/ManPages_iPhoneOS/man2/fsync.2.html
+      // fsync() on macOS flush data to the device but does not force drive
+      // flush.
+      if (fcntl (fileno (_fh), F_FULLFSYNC, 0))
+      {
+        // Some filesystems, like smbfs, do not support F_FULLFSYNC
+        // operation. In those cases, fallback to fsync.
+        if (fsync (fileno (_fh)))
+          throw format ("fsync error {1}: {2}", errno, strerror (errno));
+      }
+    #else
+      if (fsync (fileno (_fh)))
+        throw format ("fsync error {1}: {2}", errno, strerror (errno));
+    # endif
     if (fclose (_fh))
       throw format ("fclose error {1}: {2}", errno, strerror (errno));
 
@@ -816,7 +869,7 @@ bool File::write (
 ////////////////////////////////////////////////////////////////////////////////
 bool File::remove (const std::string& name)
 {
-  return unlink (expand (name).c_str ()) == 0 ? true : false;
+  return unlink (expand (name).c_str ()) == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -847,15 +900,10 @@ bool File::move (const std::string& from, const std::string& to)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-Directory::Directory ()
-{
-}
+Directory::Directory () = default;
 
 ////////////////////////////////////////////////////////////////////////////////
-Directory::Directory (const Directory& other)
-: File::File (other)
-{
-}
+Directory::Directory (const Directory& other) = default;
 
 ////////////////////////////////////////////////////////////////////////////////
 Directory::Directory (const File& other)
@@ -948,7 +996,7 @@ bool Directory::remove_directory (const std::string& dir) const
     closedir (dp);
   }
 
-  return rmdir (dir.c_str ()) ? false : true;
+  return rmdir (dir.c_str ()) == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1008,7 +1056,7 @@ bool Directory::up ()
 ////////////////////////////////////////////////////////////////////////////////
 bool Directory::cd () const
 {
-  return chdir (_data.c_str ()) == 0 ? true : false;
+  return chdir (_data.c_str ()) == 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
