@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2015 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,9 +27,9 @@
 #ifndef INCLUDED_PIG
 #define INCLUDED_PIG
 
+#include <memory>
 #include <string>
 #include <vector>
-#include <memory>
 
 class Pig
 {
@@ -40,9 +40,10 @@ public:
   bool skipN (const int quantity = 1);
   bool skipWS ();
   bool skipLiteral (const std::string&);
-  bool skipPartial (const std::string&, std::string&);
+  bool skipPartial (const std::string&, std::string&, bool ignore_case = false);
 
   bool getUntil (int, std::string&);
+  bool getUntilAscii (char, std::string&);
   bool getUntilWS (std::string&);
   bool getCharacter (int&);
   bool getDigit (int&);
