@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,13 +24,11 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <JSON.h>
-#include <utf8.h>
+#include <cerrno>
+#include <cstdlib>
 #include <sstream>
-#include <stdlib.h>
-#include <inttypes.h>
-#include <errno.h>
+#include <utf8.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 bool json::SAX::parse (const std::string& input, SAX::Sink& sink)
