@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2010 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -28,19 +28,19 @@
 #define INCLUDED_TREE
 
 #include <map>
-#include <vector>
-#include <string>
 #include <memory>
+#include <string>
+#include <vector>
 
 class Tree;
 
 class Tree
 {
 public:
-  void addBranch (std::shared_ptr <Tree>);
-  void removeBranch (std::shared_ptr <Tree>);
+  void addBranch (const std::shared_ptr <Tree>&);
+  void removeBranch (const std::shared_ptr <Tree>&);
   void removeAllBranches ();
-  void replaceBranch (std::shared_ptr <Tree>, std::shared_ptr <Tree>);
+  void replaceBranch (const std::shared_ptr <Tree>&, const std::shared_ptr <Tree>&);
 
   void attribute (const std::string&, const std::string&);
   void attribute (const std::string&, const int);
@@ -62,7 +62,7 @@ public:
   std::string dump () const;
 
 private:
-  std::string dumpNode (const std::shared_ptr <Tree>, int) const;
+  std::string dumpNode (const std::shared_ptr <Tree>&, int) const;
 
 public:
   std::string                          _name       {"Unknown"};  // Name.
