@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2019, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,8 +27,8 @@
 #ifndef INCLUDED_SHARED
 #define INCLUDED_SHARED
 
-#include <sstream>
 #include <algorithm>
+#include <sstream>
 #include <string>
 #include <vector>
 
@@ -36,7 +36,7 @@
 void wrapText (std::vector <std::string>&, const std::string&, const int, bool);
 int longestWord (const std::string&);
 int longestLine (const std::string&);
-bool extractLine (std::string&, const std::string&, int, bool, unsigned int&);
+bool extractLine (std::string&, const std::string&, int, bool, unsigned int&, char = '.');
 std::vector <std::string> split (const std::string&, const char);
 std::vector <std::string> split (const std::string&);
 std::string join (const std::string&, const std::vector<int>&);
