@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,6 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <utf8.h>
 #include <wcwidth.h>
 
@@ -268,7 +267,7 @@ unsigned int utf8_text_width (const std::string& str)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string utf8_substr (
+std::string utf8_substr (
   const std::string& input,
   unsigned int start,
   unsigned int length /* = 0 */)
