@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2015 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,14 +24,13 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Configuration.h>
 #include <test.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int main (int, char**)
 {
-  UnitTest t (20);
+  UnitTest t (21);
 
   // bool has (const std::string&);
   Configuration c1;
@@ -65,9 +64,7 @@ int main (int, char**)
   t.ok (c1.getBoolean ("boolean4") == true,    "Configuration 'boolean4' --> true");
   t.ok (c1.getBoolean ("boolean5") == true,    "Configuration 'boolean5' --> true");
 
-  // TODO void load  (const std::string&, int nest = 1);
-
-  // void parse (const std::string&, int nest = 1);
+  // void parse (const std::string&, int nest = 1, const std::vector <std::string>& search_paths = {});
   Configuration c2;
   c2.parse ("\n"
             "# Comment\n"
@@ -98,6 +95,12 @@ int main (int, char**)
   t.is (c3.get ("bar"), "2plus", "Configuration::setIfBlank changes blank values.");
   t.is (c3.get ("baz"), "3plus", "Configuration::setIfBlank sets missing values.");
 
+  // void load (const std::string&, int nest = 1, const std::vector <std::string>& search_paths = {});
+  setenv("FOO", "2.conf", 1);
+  Configuration c4;
+  c4.load ("config/1.conf", 1, { "config/nest" });
+  t.is (c4.get ("hello"), "world", "Configuration::load with search paths");
+
   return 0;
 }
 
