@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2021, Göteborg Bit Factory.
+// Copyright 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,9 +24,8 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
-#include <test.h>
 #include <Datetime.h>
+#include <test.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 void testInit (UnitTest& t, const std::string& value, Datetime& var)
@@ -52,7 +51,7 @@ void testInit (UnitTest& t, const std::string& value, Datetime& var)
 ////////////////////////////////////////////////////////////////////////////////
 int main (int, char**)
 {
-  UnitTest t (164);
+  UnitTest t (201);
 
   Datetime sunday;    testInit (t, "sunday",    sunday);
   Datetime monday;    testInit (t, "monday",    monday);
@@ -78,6 +77,22 @@ int main (int, char**)
   t.ok (friday    == fri, "friday == fri");
   t.ok (saturday  == sat, "saturday == sat");
 
+  Datetime sundayCapital;    testInit (t, "Sunday",    sundayCapital);
+  Datetime mondayCapital;    testInit (t, "Monday",    mondayCapital);
+  Datetime tuesdayCapital;   testInit (t, "Tuesday",   tuesdayCapital);
+  Datetime wednesdayCapital; testInit (t, "Wednesday", wednesdayCapital);
+  Datetime thursdayCapital;  testInit (t, "Thursday",  thursdayCapital);
+  Datetime fridayCapital;    testInit (t, "Friday",    fridayCapital);
+  Datetime saturdayCapital;  testInit (t, "Saturday",  saturdayCapital);
+
+  t.ok (sundayCapital    == sun, "Sunday == sun");
+  t.ok (mondayCapital    == mon, "Monday == mon");
+  t.ok (tuesdayCapital   == tue, "Tuesday == tue");
+  t.ok (wednesdayCapital == wed, "Wednesday == wed");
+  t.ok (thursdayCapital  == thu, "Thursday == thu");
+  t.ok (fridayCapital    == fri, "Friday == fri");
+  t.ok (saturdayCapital  == sat, "Saturday == sat");
+
   Datetime january;   testInit (t, "january",   january);
   Datetime february;  testInit (t, "february",  february);
   Datetime march;     testInit (t, "march",     march);
@@ -116,6 +131,32 @@ int main (int, char**)
   t.ok (november  == nov, "november == nov");
   t.ok (december  == dec, "december == dec");
 
+  Datetime januaryCapital;   testInit (t, "January",   januaryCapital);
+  Datetime februaryCapital;  testInit (t, "February",  februaryCapital);
+  Datetime marchCapital;     testInit (t, "March",     marchCapital);
+  Datetime aprilCapital;     testInit (t, "April",     aprilCapital);
+  Datetime mayCapital;       testInit (t, "May",       mayCapital);
+  Datetime juneCapital;      testInit (t, "June",      juneCapital);
+  Datetime julyCapital;      testInit (t, "July",      julyCapital);
+  Datetime augustCapital;    testInit (t, "August",    augustCapital);
+  Datetime septemberCapital; testInit (t, "September", septemberCapital);
+  Datetime octoberCapital;   testInit (t, "October",   octoberCapital);
+  Datetime novemberCapital;  testInit (t, "November",  novemberCapital);
+  Datetime decemberCapital;  testInit (t, "December",  decemberCapital);
+
+  t.ok (januaryCapital   == jan, "January == jan");
+  t.ok (februaryCapital  == feb, "February == feb");
+  t.ok (marchCapital     == mar, "March == mar");
+  t.ok (aprilCapital     == apr, "April == apr");
+  // May has only three letters.
+  t.ok (juneCapital      == jun, "June == jun");
+  t.ok (julyCapital      == jul, "July == jul");
+  t.ok (augustCapital    == aug, "August == aug");
+  t.ok (septemberCapital == sep, "September == sep");
+  t.ok (octoberCapital   == oct, "October == oct");
+  t.ok (novemberCapital  == nov, "November == nov");
+  t.ok (decemberCapital  == dec, "December == dec");
+
   // Simply instantiate these for now.  Test later.
   Datetime now;            testInit (t, "now", now);
   Datetime yesterday;      testInit (t, "yesterday", yesterday);
@@ -183,27 +224,27 @@ int main (int, char**)
   Datetime yesterday7;      testInit (t, "yest",      yesterday7);
   Datetime yesterday8;      testInit (t, "yes",       yesterday8);
 
-  t.ok (eod == tomorrow,            "eod == tomorrow");
-  t.ok (eom == sonm,                "eom == sonm");
+  t.ok (eod < tomorrow,             "eod  < tomorrow");
+  t.ok (eom < sonm,                 "eom  < sonm");
   t.ok (eond > tomorrow,            "eond > tomorrow");
   t.ok (eonm > sonm,                "eonm > sonm");
   t.ok (eonq > sonq,                "eonq > sonq");
   t.ok (eonw > sonw,                "eonw > sonw");
   t.ok (eonww > sonww,              "eonww > sonww");
   t.ok (eony > sony,                "eony > sony");
-  t.ok (eopd == today,              "eopd == today");
-  t.ok (eopm == som,                "eopm == som");
-  t.ok (eopq == soq,                "eopq == soq");
-  t.ok (eopw == sow,                "eopw == sow");
+  t.ok (eopd < today,               "eopd < today");
+  t.ok (eopm < som,                 "eopm < som");
+  t.ok (eopq < soq,                 "eopq < soq");
+  t.ok (eopw < sow,                 "eopw < sow");
   t.ok (eopww < soww,               "eopww < soww");
-  t.ok (eopy == soy,                "eopy == soy");
+  t.ok (eopy < soy,                 "eopy < soy");
   t.ok (eoq == eoq,                 "eoq == eoq");
-  t.ok (eoq == sonq,                "eoq == sonq");
+  t.ok (eoq < sonq,                 "eoq < sonq");
   t.ok (eow == eow,                 "eow == eow");
-  t.ok (eow == sonw,                "eow == sonw");
+  t.ok (eow < sonw,                 "eow < sonw");
   t.ok (eoww >= eopww,              "eoww >= eopww");
   t.ok (eoy == eoy,                 "eoy == eoy");
-  t.ok (eoy == sony,                "eoy == sony");
+  t.ok (eoy < sony,                 "eoy < sony");
   t.ok (later == someday,           "later == someday");
   t.ok (now < later,                "now < later");
   t.ok (now < someday,              "now < someday");
@@ -211,10 +252,10 @@ int main (int, char**)
   t.ok (sod == today,               "sod == today");
   t.ok (som < eom,                  "som < eom");
   t.ok (sond == tomorrow,           "sond == tomorrow");
-  t.ok (sonq == eoq,                "sonq == eoq");
+  t.ok (sonq > eoq,                 "sonq > eoq");
   t.ok (sonq > soq,                 "sonq > soq");
-  t.ok (sonw == eow,                "sonw == eow");
-  t.ok (sony == eoy,                "sony == eoy");
+  t.ok (sonw > eow,                 "sonw > eow");
+  t.ok (sony > eoy,                 "sony > eoy");
   t.ok (sony > soy,                 "sony > soy");
   t.ok (sopd == yesterday,          "sopd == yesterday");
   t.ok (sopm < som,                 "sopm < som");
@@ -223,7 +264,7 @@ int main (int, char**)
   t.ok (sopww < soww,               "sopww < soww");
   t.ok (sopy < soy,                 "sopy < soy");
   t.ok (sow < sonw,                 "sow < sonw");
-  t.ok (soww == sonww,              "soww == sonww");
+  t.ok (soww < sonww,               "soww < sonww");
   t.ok (soy > sopy,                 "soy > sopy");
   t.ok (today < tomorrow,           "today < tomorrow");
   t.ok (yesterday < today,          "yesterday < today");
