@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2021, Göteborg Bit Factory.
+// Copyright 2016 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,11 +24,10 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Datetime.h>
-#include <test.h>
+#include <ctime>
 #include <iostream>
-#include <time.h>
+#include <test.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 void testParse (
@@ -171,7 +170,6 @@ int main (int, char**)
   time_t f_utc1 = timegm (utc_now);
   std::cout << "# future midnight 9850-12-01 " << f_utc1 << '\n';
 
-
   int hms = (12 * 3600) + (34 * 60) + 56; // The time 12:34:56 in seconds.
   int hm  = (12 * 3600) + (34 * 60);      // The time 12:34:00 in seconds.
   int z   = 3600;                         // TZ offset.
@@ -771,43 +769,43 @@ int main (int, char**)
       if (now.dayOfWeek () >= 0)
         t.ok (r4.sameDay (now + (0 - now.dayOfWeek () + 7) * 86400), "sunday -> next sunday");
       else
-        t.ok (r4.sameDay (now + (0 - now.dayOfWeek ()) * 86400), "sunday -> next sunday");;
+        t.ok (r4.sameDay (now + (0 - now.dayOfWeek ()) * 86400), "sunday -> next sunday");
 
       Datetime r5 ("monday");
       if (now.dayOfWeek () >= 1)
         t.ok (r5.sameDay (now + (1 - now.dayOfWeek () + 7) * 86400), "monday -> next monday");
       else
-        t.ok (r5.sameDay (now + (1 - now.dayOfWeek ()) * 86400), "monday -> next monday");;
+        t.ok (r5.sameDay (now + (1 - now.dayOfWeek ()) * 86400), "monday -> next monday");
 
       Datetime r6 ("tuesday");
       if (now.dayOfWeek () >= 2)
         t.ok (r6.sameDay (now + (2 - now.dayOfWeek () + 7) * 86400), "tuesday -> next tuesday");
       else
-        t.ok (r6.sameDay (now + (2 - now.dayOfWeek ()) * 86400), "tuesday -> next tuesday");;
+        t.ok (r6.sameDay (now + (2 - now.dayOfWeek ()) * 86400), "tuesday -> next tuesday");
 
       Datetime r7 ("wednesday");
       if (now.dayOfWeek () >= 3)
         t.ok (r7.sameDay (now + (3 - now.dayOfWeek () + 7) * 86400), "wednesday -> next wednesday");
       else
-        t.ok (r7.sameDay (now + (3 - now.dayOfWeek ()) * 86400), "wednesday -> next wednesday");;
+        t.ok (r7.sameDay (now + (3 - now.dayOfWeek ()) * 86400), "wednesday -> next wednesday");
 
       Datetime r8 ("thursday");
       if (now.dayOfWeek () >= 4)
         t.ok (r8.sameDay (now + (4 - now.dayOfWeek () + 7) * 86400), "thursday -> next thursday");
       else
-        t.ok (r8.sameDay (now + (4 - now.dayOfWeek ()) * 86400), "thursday -> next thursday");;
+        t.ok (r8.sameDay (now + (4 - now.dayOfWeek ()) * 86400), "thursday -> next thursday");
 
       Datetime r9 ("friday");
       if (now.dayOfWeek () >= 5)
         t.ok (r9.sameDay (now + (5 - now.dayOfWeek () + 7) * 86400), "friday -> next friday");
       else
-        t.ok (r9.sameDay (now + (5 - now.dayOfWeek ()) * 86400), "friday -> next friday");;
+        t.ok (r9.sameDay (now + (5 - now.dayOfWeek ()) * 86400), "friday -> next friday");
 
       Datetime r10 ("saturday");
       if (now.dayOfWeek () >= 6)
         t.ok (r10.sameDay (now + (6 - now.dayOfWeek () + 7) * 86400), "saturday -> next saturday");
       else
-        t.ok (r10.sameDay (now + (6 - now.dayOfWeek ()) * 86400), "saturday -> next saturday");;
+        t.ok (r10.sameDay (now + (6 - now.dayOfWeek ()) * 86400), "saturday -> next saturday");
     }
 
     // Relative dates - look back
@@ -976,10 +974,10 @@ int main (int, char**)
     // Quarters
     Datetime soq ("soq");
     Datetime eoq ("eoq");
-    t.is (soq.day (),  1,      "soq is the first day of a month");
-    t.is (eoq.day () , 1,      "eoq is the 1st of a month");
+    t.is (soq.day (),  1,      "soq day is the first day of a quarter");
+    t.is (eoq.day () / 10 , 3, "eoq day is the last day of a quarter");
     t.is (soq.month () % 3, 1, "soq month is 1, 4, 7 or 10");
-    t.is (eoq.month () % 3, 1, "eoq month is 1, 4, 7 or 10");
+    t.is (eoq.month () % 3, 0, "eoq month is 3, 6, 9 or 12");
 
     // Note: these fail during the night of daylight savings end.
     t.ok (soq.sameYear (now) ||
