@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2019, Göteborg Bit Factory.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,6 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Duration.h>
 #include <test.h>
 
@@ -39,7 +38,7 @@ void testParse (
   int in_day,
   int in_hours,
   int in_minutes,
-  int in_seconds,
+  time_t in_seconds,
   time_t in_period,
   const std::string& output,
   const std::string& hours,
@@ -325,7 +324,7 @@ int main (int, char**)
   // 14288d 23:31:30
   t.ok (d.days ()    == 14288,      "Duration 1234567890 -> days = 14288");
   t.ok (d.hours ()   == 342935,     "Duration 1234567890 -> hours = 342935");
-  t.ok (d.minutes () == 20576131,   "Duration 1234567890 -> miniutes = 20576131");
+  t.ok (d.minutes () == 20576131,   "Duration 1234567890 -> minutes = 20576131");
   t.ok (d.seconds () == 1234567890, "Duration 1234567890 -> seconds = 123456789030");
 
   // formatVague (true)
