@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,11 +24,10 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
-#include <sstream>
-#include <iostream>
-#include <stdlib.h>
 #include <JSON.h>
+#include <cstdlib>
+#include <iostream>
+#include <sstream>
 #include <test.h>
 
 const char *positive_tests[] =
@@ -105,19 +104,19 @@ std::stringstream combined;
 class EventSink : public json::SAX::Sink
 {
 public:
-  void eventDocStart ()                            { combined << "<doc>";                            }
-  void eventDocEnd ()                              { combined << "</doc>";                           }
-  void eventObjectStart ()                         { combined << "<object>";                         }
-  void eventObjectEnd (int)                        { combined << "</object>";                        }
-  void eventArrayStart ()                          { combined << "<array>";                          }
-  void eventArrayEnd (int)                         { combined << "</array>";                         }
-  void eventName (const std::string& value)        { combined << "<name>"   << value << "</name>";   }
-  void eventValueNull ()                           { combined << "<null />";                         }
-  void eventValueBool (bool value)                 { combined << "<bool>"   << value << "</bool>";   }
-  void eventValueInt (int64_t value)               { combined << "<int>"    << value << "</int>";    }
-  void eventValueUint (uint64_t value)             { combined << "<uint>"   << value << "</uint>";   }
-  void eventValueDouble (double value)             { combined << "<double>" << value << "</double>"; }
-  void eventValueString (const std::string& value) { combined << "<string>" << value << "</string>"; }
+  void eventDocStart () override                            { combined << "<doc>";                            }
+  void eventDocEnd () override                              { combined << "</doc>";                           }
+  void eventObjectStart () override                         { combined << "<object>";                         }
+  void eventObjectEnd (int) override                        { combined << "</object>";                        }
+  void eventArrayStart () override                          { combined << "<array>";                          }
+  void eventArrayEnd (int) override                         { combined << "</array>";                         }
+  void eventName (const std::string& value) override        { combined << "<name>"   << value << "</name>";   }
+  void eventValueNull () override                           { combined << "<null />";                         }
+  void eventValueBool (bool value) override                 { combined << "<bool>"   << value << "</bool>";   }
+  void eventValueInt (int64_t value) override               { combined << "<int>"    << value << "</int>";    }
+  void eventValueUint (uint64_t value) override             { combined << "<uint>"   << value << "</uint>";   }
+  void eventValueDouble (double value) override             { combined << "<double>" << value << "</double>"; }
+  void eventValueString (const std::string& value) override { combined << "<string>" << value << "</string>"; }
 };
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -170,8 +169,7 @@ int main (int, char**)
     try
     {
       json::value* root = json::parse (negative_tests[i]);
-      t.is ((const char*) root, (const char*) NULL,
-            std::string ("negative: ") + negative_tests[i]);
+      t.is ((const char*) root, (const char*) nullptr, std::string ("negative: ") + negative_tests[i]);
     }
 
     catch (const std::string& e) { t.pass (e); }
