@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2019, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,13 +24,11 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
-#include <iostream>
-#include <stdlib.h>
-#include <string.h>
 #include <FS.h>
 #include <JSON.h>
-
+#include <cstring>
+#include <iostream>
+#include <string>
 
 ////////////////////////////////////////////////////////////////////////////////
 int main (int argc, char** argv)
