@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2018, Göteborg Bit Factory.
+// Copyright 2016 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,12 +24,10 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Lexer.h>
 #include <iostream>
-#include <vector>
-#include <string.h>
 #include <test.h>
+#include <vector>
 
 ////////////////////////////////////////////////////////////////////////////////
 int main (int, char**)
@@ -60,7 +58,7 @@ int main (int, char**)
   while (l3.token (token, type))
   {
     std::cout << "# «" << token << "» " << Lexer::typeName (type) << '\n';
-    tokens.push_back (std::pair <std::string, Lexer::Type> (token, type));
+    tokens.emplace_back (token, type);
   }
 
   t.is ((int)tokens.size (),     7,                           "7 tokens");
@@ -151,8 +149,8 @@ int main (int, char**)
     { "1.foo.bar",                                    { { "1.foo.bar",                                    Lexer::Type::word         }, NO, NO, NO, NO }, },
 
     // URL
-    { "http://tasktools.org",                         { { "http://tasktools.org",                         Lexer::Type::url          }, NO, NO, NO, NO }, },
-    { "https://bug.tasktools.org",                    { { "https://bug.tasktools.org",                    Lexer::Type::url          }, NO, NO, NO, NO }, },
+    { "http://example.com",                         { { "http://example.com",                         Lexer::Type::url          }, NO, NO, NO, NO }, },
+    { "https://foo.example.com",                    { { "https://foo.example.com",                    Lexer::Type::url          }, NO, NO, NO, NO }, },
 
     // String
     { "'one two'",                                    { { "'one two'",                                    Lexer::Type::string       }, NO, NO, NO, NO }, },
