@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2010 - 2019, Göteborg Bit Factory.
+// Copyright 2017 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,6 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <PEG.h>
 #include <test.h>
 
@@ -98,33 +97,33 @@ int main (int, char**)
   t.is (rules["this"][0][0]._token,  "that",                                       "PEG: this: that");
   t.ok (rules["this"][0][0]._quantifier == PEG::Token::Quantifier::one_or_more,    "PEG: this: that quantifier one_or_more");
   t.ok (rules["this"][0][0]._lookahead == PEG::Token::Lookahead::none,             "PEG: this: that lookahead none");
-  t.ok (rules["this"][0][0]._tags == std::set <std::string> {},                    "PEG: this: that tags {}");
+  t.ok (rules["this"][0][0]._tags.empty (),                                        "PEG: this: that tags {}");
 
   t.is (rules["that"][0][0]._token,  "other",                                      "PEG: that: other");
   t.ok (rules["that"][0][0]._quantifier == PEG::Token::Quantifier::zero_or_one,    "PEG: that: other quantifier zero_or_one");
   t.ok (rules["that"][0][0]._lookahead == PEG::Token::Lookahead::none,             "PEG: that: other lookahead none");
-  t.ok (rules["that"][0][0]._tags == std::set <std::string> {},                    "PEG: that: other tags {}");
+  t.ok (rules["that"][0][0]._tags.empty (),                                        "PEG: that: other tags {}");
 
   t.is (rules["other"][0][0]._token, "a",                                          "PEG: other: a");
   t.ok (rules["other"][0][0]._quantifier == PEG::Token::Quantifier::zero_or_more,  "PEG: other: a quantifier zero_or_more");
   t.ok (rules["other"][0][0]._lookahead == PEG::Token::Lookahead::none,            "PEG: other: a lookahead none");
-  t.ok (rules["other"][0][0]._tags == std::set <std::string> {},                   "PEG: other: a tags {}");
+  t.ok (rules["other"][0][0]._tags.empty (),                                       "PEG: other: a tags {}");
   t.is (rules["other"][0][1]._token, "a",                                          "PEG: other: a");
   t.ok (rules["other"][0][1]._quantifier == PEG::Token::Quantifier::one,           "PEG: other: a quantifier one");
   t.ok (rules["other"][0][1]._lookahead == PEG::Token::Lookahead::none,            "PEG: other: a lookahead none");
-  t.ok (rules["other"][0][1]._tags == std::set <std::string> {},                   "PEG: other: a tags {}");
+  t.ok (rules["other"][0][1]._tags.empty (),                                       "PEG: other: a tags {}");
   t.is (rules["other"][0][2]._token, "a",                                          "PEG: other: a");
   t.ok (rules["other"][0][2]._quantifier == PEG::Token::Quantifier::one,           "PEG: other: a quantifier one");
   t.ok (rules["other"][0][2]._lookahead == PEG::Token::Lookahead::positive,        "PEG: other: a lookahead positive");
-  t.ok (rules["other"][0][2]._tags == std::set <std::string> {},                   "PEG: other: a tags {}");
+  t.ok (rules["other"][0][2]._tags.empty (),                                       "PEG: other: a tags {}");
   t.is (rules["other"][0][3]._token, "a",                                          "PEG: other: a");
   t.ok (rules["other"][0][3]._quantifier == PEG::Token::Quantifier::one,           "PEG: other: a quantifier one");
   t.ok (rules["other"][0][3]._lookahead == PEG::Token::Lookahead::none,            "PEG: other: a lookahead none");
-  t.ok (rules["other"][0][3]._tags == std::set <std::string> {},                   "PEG: other: a tags {}");
+  t.ok (rules["other"][0][3]._tags.empty (),                                       "PEG: other: a tags {}");
   t.is (rules["other"][0][4]._token, "a",                                          "PEG: other: a");
   t.ok (rules["other"][0][4]._quantifier == PEG::Token::Quantifier::one,           "PEG: other: a quantifier one");
   t.ok (rules["other"][0][4]._lookahead == PEG::Token::Lookahead::negative,        "PEG: other: a lookahead negative");
-  t.ok (rules["other"][0][4]._tags == std::set <std::string> {},                   "PEG: other: a tags {}");
+  t.ok (rules["other"][0][4]._tags.empty (),                                       "PEG: other: a tags {}");
 
   t.is (rules["a"][0][0]._token,     "'a'",                                        "PEG: a: 'a'");
   t.ok (rules["a"][0][0]._quantifier == PEG::Token::Quantifier::one,               "PEG: a: 'a' quantifier one");
