@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2019, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,6 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <shared.h>
 #include <test.h>
 
@@ -150,7 +149,7 @@ int main (int, char**)
 */
 
   // std::vector <std::string> split (const std::string& input, const char delimiter)
-  std::string unsplit = "";
+  std::string unsplit;
   std::vector <std::string> items = split (unsplit, '-');
   t.is (items.size (), (size_t) 0, "split '' '-' -> 0 items");
 
