@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2010 - 2019, Göteborg Bit Factory.
+// Copyright 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,6 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <PEG.h>
 #include <Packrat.h>
 #include <test.h>
@@ -43,7 +42,7 @@ int main (int, char**)
   t.is (rules["thing"][0][0]._token,  "item",                                     "question: thing: item");
   t.ok (rules["thing"][0][0]._quantifier == PEG::Token::Quantifier::zero_or_more, "question: thing: item quantifier zero_or_more");
   t.ok (rules["thing"][0][0]._lookahead == PEG::Token::Lookahead::none,           "question: thing: item lookahead none");
-  t.ok (rules["thing"][0][0]._tags == std::set <std::string> {},                  "question: thing: item tags {}");
+  t.ok (rules["thing"][0][0]._tags.empty (),                                      "question: thing: item tags {}");
 
   t.is (rules["item"][0][0]._token,  "'a'",                                       "question: item: 'a'");
   t.ok (rules["item"][0][0]._quantifier == PEG::Token::Quantifier::one,           "question: item: 'a' quantifier one");
