@@ -6,14 +6,11 @@ import os
 import signal
 import sys
 import tempfile
+from queue import Queue, Empty
 from subprocess import Popen, PIPE, STDOUT
 from threading import Thread
-
-try:
-    from Queue import Queue, Empty
-except ImportError:
-    from queue import Queue, Empty
 from time import sleep
+
 try:
     import simplejson as json
 except ImportError:
@@ -198,7 +195,7 @@ def _get_output(arguments, timeout=None):
             # Process finished
             return _retrieve_output(t, output_timeout, outputq, "Program to die")
 
-    # This should never happen but in case something goes really bad
+    # This should never happen, but in case something goes really awry...
     raise OSError("Program stopped responding and couldn't be killed")
 
 
