@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2019, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2019, 2022, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,9 +24,9 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <timew.h>
+#include <IntervalFactory.h>
 #include <test.h>
-#include <src/IntervalFactory.h>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 void test_flatten (
