@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2016 - 2019, Thomas Lauf, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2019, 2022 - 2023, Thomas Lauf, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -24,9 +24,8 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
-#include <timew.h>
 #include <test.h>
+#include <timew.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 int main (int, char**)
@@ -45,7 +44,7 @@ int main (int, char**)
   t.is (quoteIfNeeded ("f o o"), "\"f o o\"", "quoteIfNeeded 'f o o' --> '\"f o o\"'");
 
   {
-    std::set<std::string> unjoined;
+    std::set <std::string> unjoined;
     std::string joined;
 
     joined = join("", unjoined);
